==> spotify_openapi-0.0.0.tar.gz: test/disallows_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for DisallowsObject
void main() {
  final DisallowsObject? instance = /* DisallowsObject(...) */ null;
  // TODO add properties to the entity

  group(DisallowsObject, () {
    // Interrupting playback. Optional field.
    // bool interruptingPlayback
    test('to test the property `interruptingPlayback`', () async {
      // TODO
    });

    // Pausing. Optional field.
    // bool pausing
    test('to test the property `pausing`', () async {
      // TODO
    });

    // Resuming. Optional field.
    // bool resuming
    test('to test the property `resuming`', () async {
      // TODO
    });

    // Seeking playback location. Optional field.
    // bool seeking
    test('to test the property `seeking`', () async {
      // TODO
    });

    // Skipping to the next context. Optional field.
    // bool skippingNext
    test('to test the property `skippingNext`', () async {
      // TODO
    });

    // Skipping to the previous context. Optional field.
    // bool skippingPrev
    test('to test the property `skippingPrev`', () async {
      // TODO
    });

    // Toggling repeat context flag. Optional field.
    // bool togglingRepeatContext
    test('to test the property `togglingRepeatContext`', () async {
      // TODO
    });

    // Toggling shuffle flag. Optional field.
    // bool togglingShuffle
    test('to test the property `togglingShuffle`', () async {
      // TODO
    });

    // Toggling repeat track flag. Optional field.
    // bool togglingRepeatTrack
    test('to test the property `togglingRepeatTrack`', () async {
      // TODO
    });

    // Transfering playback between devices. Optional field.
    // bool transferringPlayback
    test('to test the property `transferringPlayback`', () async {
      // TODO
    });

  });
}

==> spotify_openapi-0.0.1.tar.gz: test/disallows_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for DisallowsObject
void main() {
  //final instance = DisallowsObjectBuilder();
  // TODO add properties to the builder and call build()

  group(DisallowsObject, () {
    // Interrupting playback. Optional field.
    // bool interruptingPlayback
    test('to test the property `interruptingPlayback`', () async {
      // TODO
    });

    // Pausing. Optional field.
    // bool pausing
    test('to test the property `pausing`', () async {
      // TODO
    });

    // Resuming. Optional field.
    // bool resuming
    test('to test the property `resuming`', () async {
      // TODO
    });

    // Seeking playback location. Optional field.
    // bool seeking
    test('to test the property `seeking`', () async {
      // TODO
    });

    // Skipping to the next context. Optional field.
    // bool skippingNext
    test('to test the property `skippingNext`', () async {
      // TODO
    });

    // Skipping to the previous context. Optional field.
    // bool skippingPrev
    test('to test the property `skippingPrev`', () async {
      // TODO
    });

    // Toggling repeat context flag. Optional field.
    // bool togglingRepeatContext
    test('to test the property `togglingRepeatContext`', () async {
      // TODO
    });

    // Toggling shuffle flag. Optional field.
    // bool togglingShuffle
    test('to test the property `togglingShuffle`', () async {
      // TODO
    });

    // Toggling repeat track flag. Optional field.
    // bool togglingRepeatTrack
    test('to test the property `togglingRepeatTrack`', () async {
      // TODO
    });

    // Transfering playback between devices. Optional field.
    // bool transferringPlayback
    test('to test the property `transferringPlayback`', () async {
      // TODO
    });

  });
}
